==> qtermwidget_1.4.0.orig.tar.xz: qtermwidget-1.4.0/lib/translations/qtermwidget_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>Konsole::Session</name>
    <message>
        <location filename="../Session.cpp" line="454"/>
        <source>Bell in session &apos;%1&apos;</source>
        <translation>Κουδούνι στην συνεδρία &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="606"/>
        <source>Session &apos;%1&apos; exited with code %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="608"/>
        <source>Session &apos;%1&apos; crashed.</source>
        <translation>Η συνεδρία &apos;%1&apos; κατέρρευσε.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="613"/>
        <source>Session &apos;%1&apos; exited unexpectedly.</source>
        <translation>Η συνεδρία &apos;%1&apos; τερματίστηκε απροσδόκητα.</translation>
    </message>
</context>
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1275"/>
        <source>Size: XXX x XXX</source>
        <translation>Μέγεθος: XXX x XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1287"/>
        <source>Size: %1 x %2</source>
        <translation>Μέγεθος: %1 x %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2787"/>
        <source>Paste multiline text</source>
        <translation>Επικόλληση κειμένου πολλαπλών γραμμών</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2788"/>
        <source>Are you sure you want to paste this text?</source>
        <translation>Επιθυμείτε σίγουρα την επικόλληση του κειμένου;</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3258"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Η έξοδος έχει &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;ανασταλεί&lt;/a&gt; με τον συνδυασμό πλήκτρων Ctrl+S. Πιέστε &lt;b&gt;Ctrl+Q&lt;/b&gt; για επαναφορά.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1121"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>Δεν υπάρχει κάποιος μεταφραστής πληκτρολογίου διαθέσιμος. Η απαιτούμενη πληροφορία για την μετατροπή των πατημάτων πλήκτρων σε χαρακτήρες στο τερματικό λείπει.</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2794"/>
        <source>Show Details...</source>
        <translation>Εμφάνιση λεπτομερειών...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="275"/>
        <location filename="../ColorScheme.cpp" line="290"/>
        <source>Un-named Color Scheme</source>
        <translation>Ανώνυμος χρωματικός συνδυασμός</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="461"/>
        <source>Accessible Color Scheme</source>
        <translation>Προσπελάσιμος χρωματικός σχηματισμός</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="515"/>
        <source>Open Link</source>
        <translation>Άνοιγμα του δεσμού</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="516"/>
        <source>Copy Link Address</source>
        <translation>Αντιγραφή διεύθυνσης του δεσμού</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="520"/>
        <source>Send Email To...</source>
        <translation>Αποστολή ηλ. αλληλογραφίας προς...</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="521"/>
        <source>Copy Email Address</source>
        <translation>Αντιγραφή της ηλ. διεύθυνσης</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="469"/>
        <source>Color Scheme Error</source>
        <translation>Σφάλμα του χρωματικού συνδυασμού</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="470"/>
        <source>Cannot load color scheme: %1</source>
        <translation>Αδύνατη η φόρτωση του χρωματικού συνδυασμού: %1</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="40"/>
        <source>Match case</source>
        <translation>Ταίριασμα πεζών/κεφαλαίων</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="46"/>
        <source>Regular expression</source>
        <translation>Κανονική έκφραση</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="50"/>
        <source>Highlight all matches</source>
        <translation>Τονισμός όλων των ταιριαστών</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>Γραμμή αναζήτησης</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>Εύρεση:</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
</TS>

==> qtermwidget_2.3.0.orig.tar.xz: qtermwidget-2.3.0/lib/translations/qtermwidget_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>Konsole::Session</name>
    <message>
        <location filename="../Session.cpp" line="448"/>
        <source>Bell in session &apos;%1&apos;</source>
        <translation>Κουδούνι στην συνεδρία &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="630"/>
        <source>Session &apos;%1&apos; exited with code %2.</source>
        <translation>Η συνεδρία «%1» τερματίστηκε με τον κωδικό %2.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="632"/>
        <source>Session &apos;%1&apos; crashed.</source>
        <translation>Η συνεδρία &apos;%1&apos; κατέρρευσε.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="637"/>
        <source>Session &apos;%1&apos; exited unexpectedly.</source>
        <translation>Η συνεδρία &apos;%1&apos; τερματίστηκε απροσδόκητα.</translation>
    </message>
</context>
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1311"/>
        <source>Size: XXX x XXX</source>
        <translation>Μέγεθος: XXX x XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1323"/>
        <source>Size: %1 x %2</source>
        <translation>Μέγεθος: %1 x %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2987"/>
        <source>Paste multiline text</source>
        <translation>Επικόλληση κειμένου πολλαπλών γραμμών</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2988"/>
        <source>Are you sure you want to paste this text?</source>
        <translation>Επιθυμείτε σίγουρα την επικόλληση του κειμένου;</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3459"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Η έξοδος έχει &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;ανασταλεί&lt;/a&gt; με τον συνδυασμό πλήκτρων Ctrl+S. Πιέστε &lt;b&gt;Ctrl+Q&lt;/b&gt; για επαναφορά.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1106"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>Δεν υπάρχει κάποιος μεταφραστής πληκτρολογίου διαθέσιμος. Η απαιτούμενη πληροφορία για την μετατροπή των πατημάτων πλήκτρων σε χαρακτήρες στο τερματικό λείπει.</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2994"/>
        <source>Show Details...</source>
        <translation>Εμφάνιση λεπτομερειών...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="275"/>
        <location filename="../ColorScheme.cpp" line="290"/>
        <source>Un-named Color Scheme</source>
        <translation>Ανώνυμος χρωματικός συνδυασμός</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="461"/>
        <source>Accessible Color Scheme</source>
        <translation>Προσπελάσιμος χρωματικός σχηματισμός</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="522"/>
        <source>Open Link</source>
        <translation>Άνοιγμα του δεσμού</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="523"/>
        <source>Copy Link Address</source>
        <translation>Αντιγραφή διεύθυνσης του δεσμού</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="527"/>
        <source>Send Email To...</source>
        <translation>Αποστολή ηλ. αλληλογραφίας προς...</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="528"/>
        <source>Copy Email Address</source>
        <translation>Αντιγραφή της ηλ. διεύθυνσης</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="465"/>
        <source>Color Scheme Error</source>
        <translation>Σφάλμα του χρωματικού συνδυασμού</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="466"/>
        <source>Cannot load color scheme: %1</source>
        <translation>Αδύνατη η φόρτωση του χρωματικού συνδυασμού: %1</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="39"/>
        <source>Match case</source>
        <translation>Ταίριασμα πεζών/κεφαλαίων</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="45"/>
        <source>Regular expression</source>
        <translation>Κανονική έκφραση</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="49"/>
        <source>Highlight all matches</source>
        <translation>Τονισμός όλων των ταιριαστών</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>Γραμμή αναζήτησης</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>Εύρεση:</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
</TS>
